| [ Web Proxy ] |
| Viewing: https://raw.githubusercontent.com/yhcpp/taskflow/master/docs/SingleTaskCUDA.html | [Back] [Original] |
tf::cudaFlow provides a template method, tf::cudaFlow::single_task, for creating a task to run the given callable using a single kernel thread.
You can create a task to run a kernel function just once, i.e., using one GPU thread. This is handy when you want to set up a single or a few global variables that do not need multiple threads and will be used by multiple kernels afterwards. The following example creates a single-task kernel that sets gpu_variable to 1.
int* gpu_variable; cudaMalloc(&gpu_variable, sizeof(int)); tf::Task = taskflow.emplace([&] (tf::cudaFlow& cf) { // create a single task to set the gpu_variable to 1 tf::cudaTask set_par = cf.single_task([gpu_variable] __device__ () { *gpu_variable = 1; }) // create two kernel tasks that need access to gpu_variable tf::cudaTask kernel1 = cf.kernel(grid1, block1, shm1, my_kernel_1, ...); tf::cudaTask kernel2 = cf.kernel(grid2, block2, shm2, my_kernel_2, ...); set_par.precede(kernel1, kernel2); });
Since the callable runs on GPU, it must be declared with a __device__ specifier.
The single-task algorithm is also available in tf::cudaFlowCapturer::single_task.
Search for symbols, directories, files, pages or
modules. You can omit any prefix from the symbol or file path; adding a
: or / suffix lists all members of given symbol or
directory.
Use ↓ / ↑ to navigate through the list, Enter to go. Tab autocompletes common prefix, you can copy a link to the result using L while M produces a Markdown link.
Taskflow handbook is part of the Taskflow project, copyright Dr. Tsung-Wei Huang, 2018–2021.
Generated by Doxygen 1.8.14 and m.css.
| Web Proxy Viewer | New URL | Original Page |